<!--面包屑导航-->
<template>
  <div class="home-main-page">
    <!-- 顶部 -->
    <div class="top-container">
      <div class="item">
        <div class="value">{{ topStatistics.bookValue ? topStatistics.bookValue : 0 }}</div>
        <div class="label">总账面价值(万元)</div>
      </div>
      <div class="item">
        <div class="value">{{ topStatistics.structureArea ? topStatistics.structureArea : 0 }}</div>
        <div class="label">总建筑面积(㎡)</div>
      </div>
      <div class="item">
        <div class="value">{{ topStatistics.unconfirmArea ? topStatistics.unconfirmArea : 0 }}</div>
        <div class="label">总未确权面积(㎡)</div>
      </div>
      <div class="item">
        <div class="value">{{ topStatistics.yearEarnings ? topStatistics.yearEarnings : 0 }}</div>
        <div class="label">总可出租面积(㎡)</div>
      </div>
      <div class="item">
        <div class="value">{{ topStatistics.unusedArea ? topStatistics.unusedArea : 0 }}</div>
        <div class="label">总的闲置面积(㎡)</div>
      </div>
      <div class="item">
        <div class="value">{{ topStatistics.hireArea ? topStatistics.hireArea : 0 }}</div>
        <div class="label">总年收益(万元)</div>
      </div>

    </div>
    <!-- 中间 -->
    <div class="center-container">
      <div class="center-left">
        <div class="left-box">
          <div class="item" v-for="(item, index) in statisticsList"
            :style="{ 'border-right': (index + 1) % 2 == 0 ? 'none' : '1px solid #E6F1FF', 'border-top': index > 1 ? '1px solid #E6F1FF' : 'none' }">
            <div>
              <div class="num">{{ item.value }}</div>
              <div class="label">{{ item.label }}</div>
            </div>
          </div>
        </div>
        <div class="right-chart">
          <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-股权.png')" title="项目经营排名">
            <div class="checkBtn">
              <div class="item" :class="{ 'active': active === 1 }" @click="checkTab(1)">出租率</div>
              <div class="item" :class="{ 'active': active === 2 }" @click="checkTab(2)">收益率</div>
            </div>
          </PublicTitle>
          <div id="project-chart"></div>
        </div>
      </div>
      <div class="center-right">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-股权.png')" title="资产业态价值分析" />
        <div id="commercial-chart"></div>
      </div>
    </div>
    <!-- 底部 -->
    <div class="bottom-container">
      <div class="bottom-item">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-股权.png')" title="资产面积情况">
          <div class="checkBtn">
            <div class="item" :class="{ 'active': areaActive === 1 }" @click="checkAreaTab(1)">属性</div>
            <div class="item" :class="{ 'active': areaActive === 2 }" style="border-left: 1px solid #E6F1FF;"  @click="checkAreaTab(2)">状态</div>
            <div class="item" :class="{ 'active': areaActive === 3 }" style="border-left: 1px solid #E6F1FF;"  @click="checkAreaTab(3)">来源</div>
          </div>
        </PublicTitle>
        <div id="area-chart"></div>
      </div>
      <div class="bottom-item">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-股权.png')" title="资产盘活" />
        <div id="vitalize-chart"></div>
      </div>
      <div class="bottom-item">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-股权.png')" title="资产维修" />
        <div id="repair-chart"></div>
      </div>
      <div class="bottom-item">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-股权.png')" title="资产处置" />
        <div id="dispose-chart"></div>
      </div>
    </div>
  </div>
</template>

<script>

import * as echarts from 'echarts'
import utils from '@/utils.js'
import PublicTitle from '@/components/PublicTitle/index'

import api from '@/api/assetsOperating/assetsOperating.js'
export default {
  name: 'HomePage', // 首页
  components: {
    PublicTitle,
  },
  data() {
    return {
      colorList: ['#55edb0', '#00d4ff', '#c679e5', '#198cff'],
      active: 1,
      areaActive: 1,
      topStatistics: {
        bookValue: '135,278,743.55',
        structureArea: '1,194,337.69',
        unconfirmArea: '1,194,337.69',
        yearEarnings: '128,814,733.27',
        unusedArea: '128,814,733.27',
        hireArea: '128,814,733.27',
      },//顶部统计
      statisticsList: [
        {
          label: '应收租金(万元)',
          value: 40
        }, {
          label: '实收租金(万元)',
          value: 32
        }, {
          label: '逾期欠租数量(个)',
          value: 8
        }, {
          label: '欠收租金(万元)',
          value: 0
        }, {
          label: '新增合同(个)',
          value: 23
        }, {
          label: '续签合同(个)',
          value: 33
        }, {
          label: '到期合同(个)',
          value: 0
        },
      ],


      rentxData: ['和锦家园商业门面', '和欣家园64幢底商', '和欣家园68幢底商', '和欣家园44幢底商', '和欣家园4幢底商'],
      rentyData: [90, 80, 70, 60, 30, 20],
      areaData: [
        {
          name: '政府资产',
          value: 30,
          itemStyle: {
            color: '#198CFF',
          },
        },
        {
          name: '企业资产',
          value: 120,
          itemStyle: {
            color: '#55EDB0',
          },
        }
      ]


    }
  },
  watch: {},
  created() {

  },
  mounted() {
    this.$nextTick(() => {
      this.initProjectTop()
      this.initChat()
      this.initAreaChat()
      this.initVitalizeChat()
      this.initRepairChat()
      this.initDisposeChat()
    })

  },
  methods: {
    //字典翻译
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    checkTab(val) {
      this.active = val
      if (val == 1) {
        this.rentxData = ['和锦家园商业门面', '和欣家园64幢底商', '和欣家园68幢底商', '和欣家园44幢底商', '和欣家园4幢底商']
        this.rentyData = [90, 80, 70, 60, 30, 20]
      } else {
        this.rentxData = ['和欣家园68幢底商', '和欣家园44幢底商', '和欣家园4幢底商', '和锦家园商业门面', '和欣家园64幢底商',]
        this.rentyData = [88, 77, 66, 54, 32, 30]
      }
      this.initProjectTop()
    },
    checkAreaTab(val) {
      this.areaActive = val
      if (val === 1) {
        this.areaData = [
          {
            name: '政府资产',
            value: 30,
            itemStyle: {
              color: '#198CFF',
            },
          },
          {
            name: '企业资产',
            value: 120,
            itemStyle: {
              color: '#55EDB0',
            },
          }
        ]
      } else if (val === 2) {
        this.areaData = [
          {
            name: '闲置',
            value: 30,
          },
          {
            name: '自用',
            value: 40,
          },
          {
            name: '出租',
            value: 40,
          },
          {
            name: '被占用',
            value: 5,
          },
          {
            name: '存量',
            value: 20,
          },
          {
            name: '新增',
            value: 30,
          },
          {
            name: '其他',
            value: 10,
          }
        ]
      } else {
        this.areaData = [
          {
            name: '自建',
            value: 88,
           
          },
          {
            name: '购买',
            value: 120,
          },
          {
            name: '划拔',
            value: 40,
          },
          {
            name: '置换',
            value: 77,
          },
          {
            name: '出让',
            value: 55,
          }
        ]
      }


      this.initAreaChat()
    },
    //项目经营排名
    initProjectTop() {

      let chartDom = echarts.init(
        document.getElementById('project-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow', // 默认为直线，可选为：'line' | 'shadow'
          },
        },
        grid: {
          left: '4%',
          top: '0',
          right: '0',
          bottom: '0',
          containLabel: true,
        },
        xAxis: [
          {
            show: false,
            type: 'value',
            name: '(单位:次)',
          },
        ],
        yAxis: [
          {
            data: this.rentxData,
            inverse: true,//反向
            axisLine: {
              show: false
            },
            axisTick: {
              show: false
            },
            axisLabel: {
              fontSize: 12,
              formatter: function (value, index) {
                // var sureInd = xData.map(item => item).indexOf(value) + 1
                var sureInd = index + 1
                console.log(sureInd)
                if (sureInd == 1) {
                  return '{a|' + sureInd + '}' + '{e|' + value + '}'
                }
                else if (sureInd == 2) {
                  return '{b|' + sureInd + '}' + '{e|' + value + '}'
                } else if (sureInd == 3) {
                  return '{c|' + sureInd + '}' + '{e|' + value + '}'
                } else {
                  return '{d|' + sureInd + '}' + '{e|' + value + '}'
                }
              },
              rich: {
                a: {
                  backgroundColor: "#FFE387",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                e: {
                  color: '#666666',
                  width: 100,
                },
                b: {
                  backgroundColor: "#D0E0EB",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                c: {
                  backgroundColor: "#F3BEAC",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                d: {
                  backgroundColor: "#fff",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  align: "center",
                  lineHeight: 18,
                  borderRadius: 9,
                },
              }
            }
          },
          {

            inverse: true,//反向
            position: 'right',//坐标轴位置，移至右边
            axisLine: {
              show: false
            },
            axisTick: {
              show: false
            },
            show: false,
            data: this.rentxData,
            axisLabel: {
              color: "#333",
              formatter: function (value, index) {
                if (value.length > 7) {
                  return value.slice(0, 6) + "..."
                } else {
                  return value
                }
              }
            }
          }
        ],
        series: [
          {
            type: 'bar',
            data: this.rentyData,
            barWidth: '15',
            stack: 'user',
            label: {
              show: true, // 显示标签
              position: 'right',
              fontSize: 16,
              color: '#000',
              offset: [10, 2],
            },
            itemStyle: {
              color: {
                type: 'linear',
                x: 1,
                y: 0,
                x2: 0,
                y2: 0,
                colorStops: [
                  {
                    offset: 0,
                    color: '#198CFF', // 渐变起始颜色（绿色）
                  },
                  {
                    offset: 1,
                    color: 'rgba(25, 140, 255,0.2)', // 渐变结束颜色（深绿色）
                  },
                ],
              },
              borderRadius: [0, 3, 3, 0], // 设置圆角大小

            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
    //资产业态价值分析
    initChat() {
      let xData = ['餐饮', '零售', '品牌商家', '车位', '配套设施', '超市', '住宅', '写字楼', '行政服务', '厂房', '仓库学校', '酒店', '医院']
      let bookData = [40, 60, 40, 60, 40, 60, 40, 60, 40, 60, 60, 40, 60,]
      let structureData = [20, 30, 20, 60, 20, 30, 20, 30, 20, 30, 30, 20, 30]
      let chartDom = echarts.init(
        document.getElementById('commercial-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow', // 默认为直线，可选为：'line' | 'shadow'
          },
        },
        legend: {
          data: ['账面净值', '面积'],
          align: 'left',
          padding: [15, 0, 0, 0],
        },
        grid: {
          left: '3%',
          right: '4%',
          bottom: '3%',
          containLabel: true,
        },
        xAxis: [
          {
            type: 'category',
            data: xData,
            axisTick: {
              show: false,
            },
            axisLine: {
              show: true,
              lineStyle: {
                color: '#A1A9B2', // 浅灰色
              },
            },
          },
        ],
        yAxis: [
          {
            type: 'value',
            name: '单位：万元',
            axisLabel: {
              formatter: '{value}',
            },
            splitLine: {
              show: false,
            },
            axisLine: {
              show: true,
              lineStyle: {
                color: '#A1A9B2', // 浅灰色
              },
            },
          },
          {
            type: 'value',
            name: '单位：㎡',
            axisLabel: {
              formatter: '{value}',
            },
            position: 'right',
            splitLine: {
              show: false,
            },
            axisLine: {
              show: true,
              lineStyle: {
                color: '#A1A9B2', // 浅灰色
              },
            },
          },
        ],
        series: [
          {
            name: '账面净值',
            type: 'bar',
            data: bookData,
            barWidth: '15',
            yAxisIndex: 0,
            itemStyle: {
              color: {
                type: 'linear',
                x: 0,
                y: 0,
                x2: 0,
                y2: 1,
                colorStops: [
                  {
                    offset: 0,
                    color: '#55EDB0', // 渐变起始颜色（绿色）
                  },
                  {
                    offset: 1,
                    color: 'rgba(85,237,176,0.2)', // 渐变结束颜色（深绿色）
                  },
                ],
              },
              borderRadius: [3, 3, 0, 0], // 设置圆角大小
            },
          },
          {
            name: '面积',
            type: 'line',
            data: structureData,
            // barWidth: '15',
            yAxisIndex: 1,
            itemStyle: {
              color: '#198CFF'
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
    // 资产面积情况
    initAreaChat() {
      let chartDom = echarts.init(document.getElementById('area-chart'))
      let option = {
        tooltip: {
          trigger: 'item',
        },
        legend: {
          x: 'right',
          align: 'left',
          top: 'center',
          orient: 'vertical',

        },
        series: [
          {
            name: '面积',
            type: 'pie',
            radius: ['55%', '67%'],
            center: ['35.6%', '48.4%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderColor: '#fff',
              borderWidth: 2,
            },
            label: {
              show: false,
              position: 'center',
            },

            emphasis: {
              label: {
                show: true,
                fontSize: 30,
                formatter: function (params) {
                  return [
                    '{num|' +
                    params.value +
                    '}' +
                    '{unit|个}',
                    '{label|' + params.name + '}',
                  ].join('\n')
                },
                rich: {
                  num: {
                    fontSize: 30,
                    color: '#000',
                    lineHeight: 30,
                    fontWeight: 700,
                  },
                  unit: {
                    fontSize: 14,
                    color: '#111',
                    lineHeight: 30,
                    padding: [0, 5],
                  },
                  label: {
                    fontSize: 20,
                    lineHeight: 30,
                    color: '#444',
                  },
                },
              },
            },
            labelLine: {
              show: false,
            },
            data: this.areaData,
          },
          {
            type: 'pie',
            radius: ['50%', '50%'],
            center: ['35.6%', '48.4%'],
            hoverAnimation: false,
            clockWise: false,
            cursor: 'default',
            itemStyle: {
              normal: {
                borderWidth: 2,
                borderColor: '#eaeaea',
              },
            },
            tooltip: {
              show: false,
            },
            label: {
              show: false,
            },
            data: [100],
          },
          {
            type: 'gauge',
            radius: '98%',
            center: ['35.6%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 200, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 15,
              lineStyle: {
                color: '#eaeaea',
                width: 1,
              },
            },
            axisLabel: {
              show: false,
            },
          },
          {
            type: 'gauge',
            radius: '83.5%',
            center: ['35.6%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 140, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 1,
              lineStyle: {
                color: '#eaeaea',
                width: 2,
              },
            },
            axisLabel: {
              show: false,
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
      handleChartLoop(option, chartDom);
      // 饼图自动轮播
      function handleChartLoop(option, myChart) {
        if (!myChart) {
          return
        }
        let currentIndex = 0 // 当前高亮图形在饼图数据中的下标
        highlightPie()
        // 取消所有高亮并高亮当前图形
        function highlightPie() {
          // 遍历饼图数据，取消所有图形的高亮效果
          for (var idx in option.series[0].data) {
            myChart.dispatchAction({
              type: 'downplay',
              seriesIndex: 0,
              dataIndex: idx
            })
          }
          // 高亮当前图形
          myChart.dispatchAction({
            type: 'highlight',
            seriesIndex: 0,
            dataIndex: currentIndex
          })
        }
        // // 用户鼠标悬浮到某一图形时，停止自动切换并高亮鼠标悬浮的图形
        myChart.on('mouseover', (params) => {
          if (params.componentType == 'graphic') {
            return
          }
          currentIndex = params.dataIndex
          highlightPie()
        })
      }
    },
    //资产盘活
    initVitalizeChat() {
      let echartsData = [
        {
          name: '待盘活',
          value: 30,
          itemStyle: {
            color: '#FFAE5E',
          },
        },
        {
          name: '已盘活',
          value: 120,
          itemStyle: {
            color: '#55EDB0',
          },
        }
      ]

      let chartDom = echarts.init(document.getElementById('vitalize-chart'))
      let option = {
        tooltip: {
          trigger: 'item',
        },
        legend: {
          x: 'right',
          align: 'left',
          top: 'center',
          orient: 'vertical',

        },
        series: [
          {
            name: '面积',
            type: 'pie',
            radius: ['55%', '67%'],
            center: ['35.6%', '48.4%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderColor: '#fff',
              borderWidth: 2,
            },
            label: {
              show: false,
              position: 'center',
            },

            emphasis: {
              label: {
                show: true,
                fontSize: 30,
                formatter: function (params) {
                  return [
                    '{num|' +
                    params.percent +
                    '}' +
                    '{unit|%}',
                    '{label|' + params.name + '}',
                  ].join('\n')
                },
                rich: {
                  num: {
                    fontSize: 30,
                    color: '#000',
                    lineHeight: 30,
                    fontWeight: 700,
                  },
                  unit: {
                    fontSize: 14,
                    color: '#111',
                    lineHeight: 30,
                    padding: [0, 5],
                  },
                  label: {
                    fontSize: 20,
                    lineHeight: 30,
                    color: '#444',
                  },
                },
              },
            },
            labelLine: {
              show: false,
            },
            data: echartsData,
          },
          {
            type: 'pie',
            radius: ['50%', '50%'],
            center: ['35.6%', '48.4%'],
            hoverAnimation: false,
            clockWise: false,
            cursor: 'default',
            itemStyle: {
              normal: {
                borderWidth: 2,
                borderColor: '#eaeaea',
              },
            },
            tooltip: {
              show: false,
            },
            label: {
              show: false,
            },
            data: [100],
          },
          {
            type: 'gauge',
            radius: '98%',
            center: ['35.6%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 200, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 15,
              lineStyle: {
                color: '#eaeaea',
                width: 1,
              },
            },
            axisLabel: {
              show: false,
            },
          },
          {
            type: 'gauge',
            radius: '83.5%',
            center: ['35.6%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 140, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 1,
              lineStyle: {
                color: '#eaeaea',
                width: 2,
              },
            },
            axisLabel: {
              show: false,
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
      handleChartLoop(option, chartDom);
      // 饼图自动轮播
      function handleChartLoop(option, myChart) {
        if (!myChart) {
          return
        }
        let currentIndex = 0 // 当前高亮图形在饼图数据中的下标
        highlightPie()
        // 取消所有高亮并高亮当前图形
        function highlightPie() {
          // 遍历饼图数据，取消所有图形的高亮效果
          for (var idx in option.series[0].data) {
            myChart.dispatchAction({
              type: 'downplay',
              seriesIndex: 0,
              dataIndex: idx
            })
          }
          // 高亮当前图形
          myChart.dispatchAction({
            type: 'highlight',
            seriesIndex: 0,
            dataIndex: currentIndex
          })
        }
        // // 用户鼠标悬浮到某一图形时，停止自动切换并高亮鼠标悬浮的图形
        myChart.on('mouseover', (params) => {
          if (params.componentType == 'graphic') {
            return
          }
          currentIndex = params.dataIndex
          highlightPie()
        })
      }
    },
    //资产维修
    initRepairChat() {
      let echartsData = [
        {
          name: '待维修',
          value: 30,
          itemStyle: {
            color: '#FFAE5E',
          },
        },
        {
          name: '已完成',
          value: 120,
          itemStyle: {
            color: '#55EDB0',
          },
        }
      ]

      let chartDom = echarts.init(document.getElementById('repair-chart'))
      let option = {
        tooltip: {
          trigger: 'item',
        },
        legend: {
          x: 'right',
          align: 'left',
          top: 'center',
          orient: 'vertical',

        },
        series: [
          {
            name: '面积',
            type: 'pie',
            radius: ['55%', '67%'],
            center: ['35.6%', '48.4%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderColor: '#fff',
              borderWidth: 2,
            },
            label: {
              show: false,
              position: 'center',
            },

            emphasis: {
              label: {
                show: true,
                fontSize: 30,
                formatter: function (params) {
                  return [
                    '{num|' +
                    params.percent +
                    '}' +
                    '{unit|%}',
                    '{label|' + params.name + '}',
                  ].join('\n')
                },
                rich: {
                  num: {
                    fontSize: 30,
                    color: '#000',
                    lineHeight: 30,
                    fontWeight: 700,
                  },
                  unit: {
                    fontSize: 14,
                    color: '#111',
                    lineHeight: 30,
                    padding: [0, 5],
                  },
                  label: {
                    fontSize: 20,
                    lineHeight: 30,
                    color: '#444',
                  },
                },
              },
            },
            labelLine: {
              show: false,
            },
            data: echartsData,
          },
          {
            type: 'pie',
            radius: ['50%', '50%'],
            center: ['35.6%', '48.4%'],
            hoverAnimation: false,
            clockWise: false,
            cursor: 'default',
            itemStyle: {
              normal: {
                borderWidth: 2,
                borderColor: '#eaeaea',
              },
            },
            tooltip: {
              show: false,
            },
            label: {
              show: false,
            },
            data: [100],
          },
          {
            type: 'gauge',
            radius: '98%',
            center: ['35.6%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 200, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 15,
              lineStyle: {
                color: '#eaeaea',
                width: 1,
              },
            },
            axisLabel: {
              show: false,
            },
          },
          {
            type: 'gauge',
            radius: '83.5%',
            center: ['35.6%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 140, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 1,
              lineStyle: {
                color: '#eaeaea',
                width: 2,
              },
            },
            axisLabel: {
              show: false,
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
      handleChartLoop(option, chartDom);
      // 饼图自动轮播
      function handleChartLoop(option, myChart) {
        if (!myChart) {
          return
        }
        let currentIndex = 0 // 当前高亮图形在饼图数据中的下标
        highlightPie()
        // 取消所有高亮并高亮当前图形
        function highlightPie() {
          // 遍历饼图数据，取消所有图形的高亮效果
          for (var idx in option.series[0].data) {
            myChart.dispatchAction({
              type: 'downplay',
              seriesIndex: 0,
              dataIndex: idx
            })
          }
          // 高亮当前图形
          myChart.dispatchAction({
            type: 'highlight',
            seriesIndex: 0,
            dataIndex: currentIndex
          })
        }
        // // 用户鼠标悬浮到某一图形时，停止自动切换并高亮鼠标悬浮的图形
        myChart.on('mouseover', (params) => {
          if (params.componentType == 'graphic') {
            return
          }
          currentIndex = params.dataIndex
          highlightPie()
        })
      }
    },
    //资产处置
    initDisposeChat() {
      let echartsData = [
        {
          name: '资产报废',
          value: 30,
          itemStyle: {
            color: '#198CFF',
          },
        },
        {
          name: '资产转让',
          value: 120,
          itemStyle: {
            color: '#55EDB0',
          },
        }
      ]

      let chartDom = echarts.init(document.getElementById('dispose-chart'))
      let option = {
        tooltip: {
          trigger: 'item',
        },
        legend: {
          x: 'right',
          align: 'left',
          top: 'center',
          orient: 'vertical',

        },
        series: [
          {
            name: '面积',
            type: 'pie',
            radius: ['55%', '67%'],
            center: ['35.6%', '48.4%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderColor: '#fff',
              borderWidth: 2,
            },
            label: {
              show: false,
              position: 'center',
            },

            emphasis: {
              label: {
                show: true,
                fontSize: 30,
                formatter: function (params) {
                  return [
                    '{num|' +
                    params.value +
                    '}' +
                    '{unit|个}',
                    '{label|' + params.name + '}',
                  ].join('\n')
                },
                rich: {
                  num: {
                    fontSize: 30,
                    color: '#000',
                    lineHeight: 30,
                    fontWeight: 700,
                  },
                  unit: {
                    fontSize: 14,
                    color: '#111',
                    lineHeight: 30,
                    padding: [0, 5],
                  },
                  label: {
                    fontSize: 20,
                    lineHeight: 30,
                    color: '#444',
                  },
                },
              },
            },
            labelLine: {
              show: false,
            },
            data: echartsData,
          },
          {
            type: 'pie',
            radius: ['50%', '50%'],
            center: ['35.6%', '48.4%'],
            hoverAnimation: false,
            clockWise: false,
            cursor: 'default',
            itemStyle: {
              normal: {
                borderWidth: 2,
                borderColor: '#eaeaea',
              },
            },
            tooltip: {
              show: false,
            },
            label: {
              show: false,
            },
            data: [100],
          },
          {
            type: 'gauge',
            radius: '98%',
            center: ['35.6%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 200, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 15,
              lineStyle: {
                color: '#eaeaea',
                width: 1,
              },
            },
            axisLabel: {
              show: false,
            },
          },
          {
            type: 'gauge',
            radius: '83.5%',
            center: ['35.6%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 140, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 1,
              lineStyle: {
                color: '#eaeaea',
                width: 2,
              },
            },
            axisLabel: {
              show: false,
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
      handleChartLoop(option, chartDom);
      // 饼图自动轮播
      function handleChartLoop(option, myChart) {
        if (!myChart) {
          return
        }
        let currentIndex = 0 // 当前高亮图形在饼图数据中的下标
        highlightPie()
        // 取消所有高亮并高亮当前图形
        function highlightPie() {
          // 遍历饼图数据，取消所有图形的高亮效果
          for (var idx in option.series[0].data) {
            myChart.dispatchAction({
              type: 'downplay',
              seriesIndex: 0,
              dataIndex: idx
            })
          }
          // 高亮当前图形
          myChart.dispatchAction({
            type: 'highlight',
            seriesIndex: 0,
            dataIndex: currentIndex
          })
        }
        // // 用户鼠标悬浮到某一图形时，停止自动切换并高亮鼠标悬浮的图形
        myChart.on('mouseover', (params) => {
          if (params.componentType == 'graphic') {
            return
          }
          currentIndex = params.dataIndex
          highlightPie()
        })
      }
    },

  },
  beforeDestroy() { },
}
</script>

<style lang="scss" scoped>
.home-main-page {
  box-sizing: border-box;
  padding: 15px 0;
  width: 100%;
  height: 100%;
  padding: 16px 24px;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  align-items: center;

  .top-container {
    width: 100%;
    height: 16%;
    display: flex;
    background: linear-gradient(180deg, #CCE5FF 0%, #EEF8FF 100%);
    border-radius: 16px 16px 16px 16px;
    opacity: 1;
    border: 1px solid;
    border-image: linear-gradient(180deg, rgba(238.00000101327896, 248.0000004172325, 255, 1), rgba(255, 255, 255, 1)) 1 1;
    padding: 24px 0;
    box-sizing: border-box;

    .item {
      flex: 1;
      display: flex;
      flex-direction: column;
      justify-content: center;
      align-items: center;
      border-right: 1px solid #fff;

      .value {
        font-size: 26px;
        font-weight: 700;
        color: #0f2a4d;
      }

      .label {
        font-size: 16px;
        font-weight: 700;
        color: #0f2a4d;
      }

      &:nth-child(6) {
        border-right: none;
      }
    }
  }

  .center-container {
    width: 100%;
    height: 40%;
    display: flex;
    justify-content: space-between;

    .center-left {
      width: calc(50% - 8px);
      height: 100%;
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;
      display: flex;
      justify-content: space-between;

      .left-box {
        width: 40%;
        height: 100%;
        display: flex;
        flex-wrap: wrap;
        justify-content: space-between;
        border: 1px solid #E6F1FF;
        box-sizing: border-box;
        border-radius: 4px;

        .item {
          width: 50%;
          box-sizing: border-box;
          text-align: center;
          display: flex;
          flex-direction: column;
          justify-content: space-evenly;

          .num {
            font-size: 26px;
            font-family: Microsoft YaHei, Microsoft YaHei;
            font-weight: 700;
            color: #0F2A4D;
            // line-height: 34px;
          }

          .label {
            font-size: 16px;
            font-family: Microsoft YaHei, Microsoft YaHei;
            font-weight: 400;
            color: #7A8899;
            // line-height: 21px;
          }
        }
      }
    }

    .right-chart {
      width: calc(60% - 10px);
      height: 100%;

      #project-chart {
        width: 100%;
        height: calc(100% - 30px);
      }


    }

    .center-right {
      width: calc(50% - 8px);
      height: 100%;
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #commercial-chart {
        width: 100%;
        height: calc(100% - 30px);
      }

    }
  }

  .bottom-container {
    width: 100%;
    height: 40%;
    display: flex;
    justify-content: space-between;

    .bottom-item {
      width: calc(25% - 12px);
      height: 100%;
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #area-chart {
        width: 100%;
        height: calc(100% - 30px);
      }

      #vitalize-chart {
        width: 100%;
        height: calc(100% - 30px);
      }

      #repair-chart {
        width: 100%;
        height: calc(100% - 30px);
      }

      #dispose-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }
  }

  .checkBtn {
    display: flex;
    border: 1px solid #198CFF;
    border-radius: 4px 4px 4px 4px;
    line-height: 24px;
    cursor: pointer;

    .item {
      width: 58px;
      border-radius: 0px 0px 0px 0px;
      opacity: 1;
      text-align: center;
    }

    .active {
      background: #198CFF;
      color: #fff;
    }
  }
}
</style>
